@@ -4,8 +4,10 @@ use Math::GMP;
 
 $test = 0;
 $| = 1;
-print "1..247\n";
-while (<DATA>) {
+@data = <DATA>;
+@tests = grep { ! /^&/ } @data;
+print "1..", scalar @tests, "\n";
+while (defined($_ = shift @data)) {
   chop;
   if (s/^&//) {
     $f = $_;
@@ -13,7 +15,12 @@ while (<DATA>) {
     ++$test;
     @args = split(/:/,$_,99);
     $ans = pop(@args);
-    $try = "\$x = new Math::GMP \"$args[0]\";";
+    if ( $args[0] =~ /^i([-+]?\d+)$/ ) {
+      $try = "\$x = $1;";
+    }
+    else {
+      $try = "\$x = new Math::GMP \"$args[0]\";";
+    }
     if ($f eq "bnorm") {
       $try .= "\$x+0;";
     } elsif ($f eq "bneg") {
@@ -21,7 +28,12 @@ while (<DATA>) {
     } elsif ($f eq "babs") {
       $try .= "abs \$x;";
     } else {
-      $try .= "\$y = new Math::GMP \"$args[1]\";";
+      if ( $args[1] =~ /^i([-+]?\d+)$/ ) {
+	$try .= "\$y = $1;";
+      }
+      else {
+	$try .= "\$y = new Math::GMP \"$args[1]\";";
+      } 
       if ($f eq bcmp) {
 	$try .= "\$x <=> \$y;";
       } elsif ($f eq badd) {
@@ -72,6 +84,9 @@ __END__
 -123:-124:1
 -124:-123:-1
 +100:5:1
+i+100:5:1
++100:i5:1
+i-10:-10:0
 &badd
 +0:0:0
 +1:0:1
@@ -89,10 +104,12 @@ __END__
 +99999:1:100000
 +999999:1:1000000
 +9999999:1:10000000
+i+9999999:1:10000000
 +99999999:1:100000000
 +999999999:1:1000000000
 +9999999999:1:10000000000
 +99999999999:1:100000000000
++99999999999:i1:100000000000
 +10:-1:9
 +100:-1:99
 +1000:-1:999
@@ -128,6 +145,7 @@ __END__
 +999999999:1:999999998
 +9999999999:1:9999999998
 +99999999999:1:99999999998
++99999999999:i1:99999999998
 +10:-1:11
 +100:-1:101
 +1000:-1:1001
@@ -142,6 +160,7 @@ __END__
 -123456789:987654321:-1111111110
 -123456789:-987654321:864197532
 +123456789:-987654321:1111111110
+i4:12345678987:-12345678983
 &bmul
 +0:0:0
 +0:1:0
@@ -164,6 +183,8 @@ __END__
 +100010001:100010001:10002000300020001
 +10000100001:10000100001:100002000030000200001
 +11111111111:9:99999999999
++11111111111:i9:99999999999
+i9:+11111111111:99999999999
 +22222222222:9:199999999998
 +33333333333:9:299999999997
 +44444444444:9:399999999996
@@ -182,6 +203,7 @@ __END__
 +1:2:0
 +2:1:2
 +1000000000:9:111111111
++1000000000:i9:111111111
 +2000000000:9:222222222
 +3000000000:9:333333333
 +4000000000:9:444444444
@@ -198,6 +220,7 @@ __END__
 +100:4:25
 +1000:8:125
 +10000:16:625
+i+10000:16:625
 +999999999999:9:111111111111
 +999999999999:99:10101010101
 +999999999999:999:1001001001
@@ -213,6 +236,7 @@ __END__
 +1:2:1
 +2:1:0
 +1000000000:9:1
++1000000000:i9:1
 +2000000000:9:2
 +3000000000:9:3
 +4000000000:9:4
@@ -222,6 +246,7 @@ __END__
 +8000000000:9:8
 +9000000000:9:0
 +35500000:113:33
+i+35500000:113:33
 +71000000:226:66
 +106500000:339:99
 +1000000000:3:1
